@@ -4,7 +4,12 @@ function(mfdim = c(1, 1), title = TRUE)
 #-------------------------------------------------------------------------------
 {
    top <- ifelse(title, 3 + mfdim[1], 0)
-   par(mfrow = mfdim, mar = c(5, 4, 2, 2) + 0.1,
-       oma = c(0, 0, top, 0))
+
+   val <- boa.par("par")
+   val$mfrow <- mfdim
+   val$mfcol <- NULL
+   val$oma <- c(0, 0, top, 0)
+   par(val)
+       
    invisible()
 }
